summaryrefslogtreecommitdiffstats
path: root/kstars/kstars/tools/astrocalc.h
diff options
context:
space:
mode:
Diffstat (limited to 'kstars/kstars/tools/astrocalc.h')
-rw-r--r--kstars/kstars/tools/astrocalc.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kstars/kstars/tools/astrocalc.h b/kstars/kstars/tools/astrocalc.h
index c88bd104..fe8b5f49 100644
--- a/kstars/kstars/tools/astrocalc.h
+++ b/kstars/kstars/tools/astrocalc.h
@@ -60,7 +60,7 @@ Q_OBJECT
TQ_OBJECT
public:
/** construtor */
- AstroCalc(TQWidget *tqparent = 0);
+ AstroCalc(TQWidget *parent = 0);
/** destructor */
~AstroCalc();
@@ -101,7 +101,7 @@ TQ_OBJECT
/**Generate frame for Precession frame. */
void genPrecFrame(void);
/**Generate frame for aptqparent coordinates frame. */
void genAppFrame(void);
/**Generate frame for horizontal coordinates frame. */
@@ -137,7 +137,7 @@ TQ_OBJECT
TQVBox *vbox, *rightBox;
TQString previousElection;
- enum typeOfPanel {GenText, TimeText, GeoText, SolarText, CoordText, JD, SidTime, DayLength, Equinox, GeoCoord, Galactic, Precessor, Aptqparent, Azel, Planets, Ecliptic, AngDist, Vlsr};
+ enum typeOfPanel {GenText, TimeText, GeoText, SolarText, CoordText, JD, SidTime, DayLength, Equinox, GeoCoord, Galactic, Precessor, Apparent, Azel, Planets, Ecliptic, AngDist, Vlsr};
typeOfPanel rightPanel;
modCalcJD *JDFrame;
@@ -101,7 +101,7 @@ TQ_OBJECT
/**Generate frame for Precession frame. */
void genPrecFrame(void);
- /**Generate frame for aptqparent coordinates frame. */
+ /**Generate frame for apparent coordinates frame. */
void genAppFrame(void);
/**Generate frame for horizontal coordinates frame. */